@@ -650,6 +650,20 @@ class Statement(Workflow, ModelSQL, ModelView):
     def reconcile(cls, statements):
         pass
 
+    @classmethod
+    def copy(cls, statements, default=None):
+        default = default.copy() if default is not None else {}
+        new_statements = []
+        for origins, sub_statements in groupby(
+                statements, key=lambda s: bool(s.origins)):
+            sub_statements = list(sub_statements)
+            sub_default = default.copy()
+            if origins:
+                sub_default.setdefault('lines')
+            new_statements.extend(super().copy(
+                    statements, default=sub_default))
+        return new_statements
+
 
 def origin_mixin(_states, _depends):
     class Mixin:
@@ -1124,6 +1138,12 @@ class Origin(origin_mixin(_states, _depends), ModelSQL, ModelView):
                 group_by=table.id))
         return [('id', 'in', query)]
 
+    @classmethod
+    def copy(cls, origins, default=None):
+        default = default.copy() if default is not None else {}
+        default.setdefault('lines')
+        return super().copy(origins, default=default)
+
 
 del _states, _depends
 
